[Gluster-Maintainers] [gluster-packaging] glusterfs-3.8rc1 has been released for testing

Patrick Matthäi pmatthaei at debian.org
Tue May 17 10:43:15 UTC 2016


Hi,

I have attached a few patches for this release. Please add them for 3.8.x.


Am 16.05.2016 um 15:13 schrieb Niels de Vos:
> Hi,
>
> I've tagged and released glusterfs-3.8rc1. This is the 1st Release
> Candidate for GlusterFS 3.8.0.
>
>   https://build.gluster.org/job/release/159/console
>   http://bits.gluster.org/pub/gluster/glusterfs/src/glusterfs-3.8rc1.tar.gz
>
> The release-notes still need some work for a GA release:
>   https://github.com/gluster/glusterfs/blob/release-3.8/doc/release-notes/3.8.0.md
>
> Please start testing (in case you're not testing the nightly builds
> yet). We need a description of the steps that users can follow to
> upgrade from 3.7 to 3.8.
>
> Once we have some useful release-notes, we can send out a notification
> to the users list and other more public channels.
>
> Packages for CentOS-7 are available from the Community Build System,
> syncing to the standard gluster38-test repository will happen later:
>   http://cbs.centos.org/koji/buildinfo?buildID=11095
>
> Other distributions may want to verify their packaging too already.
>
> There are a few more patches proposed for 3.8, reviews for these are
> appreciated as well:
>   http://review.gluster.org/#/q/project:glusterfs+branch:release-3.8+status:open
>
> The current plan is to release 3.8.0 at the end of May, or in the first
> few days of June.
>
> Cheers,
> Niels
>
>
> _______________________________________________
> packaging mailing list
> packaging at gluster.org
> http://www.gluster.org/mailman/listinfo/packaging

-- 
/*
Mit freundlichem Gruß / With kind regards,
 Patrick Matthäi
 GNU/Linux Debian Developer

  Blog: http://www.linux-dev.org/
E-Mail: pmatthaei at debian.org
        patrick at linux-dev.org
*/

-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://www.gluster.org/pipermail/maintainers/attachments/20160517/c86d3e63/attachment-0001.html>
-------------- next part --------------
# Fix again more spelling errors.

diff -Naur glusterfs-3.8rc1.orig/cli/src/cli-xml-output.c glusterfs-3.8rc1/cli/src/cli-xml-output.c
--- glusterfs-3.8rc1.orig/cli/src/cli-xml-output.c	2016-05-16 13:23:04.677008731 +0200
+++ glusterfs-3.8rc1/cli/src/cli-xml-output.c	2016-05-17 11:57:19.152631975 +0200
@@ -5618,7 +5618,7 @@
                 }
                 break;
         default:
-                gf_log ("cli", GF_LOG_ERROR, "Uknown config command :%d",
+                gf_log ("cli", GF_LOG_ERROR, "Unknown config command :%d",
                         config_command);
                 ret = -1;
                 goto out;
diff -Naur glusterfs-3.8rc1.orig/geo-replication/src/peer_mountbroker.in glusterfs-3.8rc1/geo-replication/src/peer_mountbroker.in
--- glusterfs-3.8rc1.orig/geo-replication/src/peer_mountbroker.in	2016-05-16 13:23:04.711008905 +0200
+++ glusterfs-3.8rc1/geo-replication/src/peer_mountbroker.in	2016-05-17 11:57:19.152631975 +0200
@@ -159,11 +159,11 @@
 
     parser_useradd.add_argument('username', help="Username", type=str)
     parser_useradd.add_argument('volumes', type=str, default='',
-                                help="Volumes list. ',' seperated")
+                                help="Volumes list. ',' separated")
 
     parser_volumedel.add_argument('username', help="Username", type=str)
     parser_volumedel.add_argument('volumes', type=str, default='',
-                                help="Volumes list. ',' seperated")
+                                help="Volumes list. ',' separated")
 
     parser_userdel.add_argument('username', help="Username", type=str)
 
diff -Naur glusterfs-3.8rc1.orig/libglusterfs/src/fd-lk.c glusterfs-3.8rc1/libglusterfs/src/fd-lk.c
--- glusterfs-3.8rc1.orig/libglusterfs/src/fd-lk.c	2016-05-16 13:23:04.730009002 +0200
+++ glusterfs-3.8rc1/libglusterfs/src/fd-lk.c	2016-05-17 11:57:19.152631975 +0200
@@ -446,7 +446,7 @@
         lk_ctx = fd_lk_ctx_ref (fd->lk_ctx);
         lk     = fd_lk_ctx_node_new (cmd, flock);
 
-        gf_msg_debug ("fd-lk", 0, "new lock requrest: owner = %s, fl_type = %s"
+        gf_msg_debug ("fd-lk", 0, "new lock request: owner = %s, fl_type = %s"
                       ", fs_start = %"PRId64", fs_end = %"PRId64", user_flock:"
                       " l_type = %s, l_start = %"PRId64", l_len = %"PRId64,
                       lkowner_utoa (&flock->l_owner),
diff -Naur glusterfs-3.8rc1.orig/xlators/features/changetimerecorder/src/ctr-xlator-ctx.c glusterfs-3.8rc1/xlators/features/changetimerecorder/src/ctr-xlator-ctx.c
--- glusterfs-3.8rc1.orig/xlators/features/changetimerecorder/src/ctr-xlator-ctx.c	2016-05-16 13:23:04.856009647 +0200
+++ glusterfs-3.8rc1/xlators/features/changetimerecorder/src/ctr-xlator-ctx.c	2016-05-17 11:57:19.152631975 +0200
@@ -156,7 +156,7 @@
         if (!ctr_hard_link) {
                 gf_msg (this->name, GF_LOG_ERROR, 0,
                         CTR_MSG_HARDLINK_MISSING_IN_LIST,
-                        "Hard link doesnt exist in the list");
+                        "Hard link doesn't exist in the list");
                 goto out;
         }
 
@@ -195,7 +195,7 @@
         ctr_hard_link = ctr_search_hard_link_ctx (this, ctr_xlator_ctx,
                                                 old_pgfid, old_base_name);
         if (!ctr_hard_link) {
-                gf_msg_trace (this->name, 0, "Hard link doesnt exist"
+                gf_msg_trace (this->name, 0, "Hard link doesn't exist"
                               " in the list");
                 /* Since the hard link is not present in the list
                  * we add it to the list */
diff -Naur glusterfs-3.8rc1.orig/xlators/mgmt/glusterd/src/glusterd-volume-set.c glusterfs-3.8rc1/xlators/mgmt/glusterd/src/glusterd-volume-set.c
--- glusterfs-3.8rc1.orig/xlators/mgmt/glusterd/src/glusterd-volume-set.c	2016-05-16 13:23:04.892009831 +0200
+++ glusterfs-3.8rc1/xlators/mgmt/glusterd/src/glusterd-volume-set.c	2016-05-17 11:57:19.156631945 +0200
@@ -2745,7 +2745,7 @@
           .description = "Its a Change Time Recorder Xlator option to "
                          "enable recording write heat on metadata of the file. "
                          "The default is disabled. "
-                         "Metadata is inode atttributes like atime, mtime,"
+                         "Metadata is inode attributes like atime, mtime,"
                          " permissions etc and "
                          "extended attributes of a file ."
         },
-------------- next part --------------
# Fix again and again more and more spelling errors.

diff -Naur glusterfs-3.8rc1.orig/cli/src/cli-cmd-parser.c glusterfs-3.8rc1/cli/src/cli-cmd-parser.c
--- glusterfs-3.8rc1.orig/cli/src/cli-cmd-parser.c	2016-05-16 13:23:04.667008680 +0200
+++ glusterfs-3.8rc1/cli/src/cli-cmd-parser.c	2016-05-17 11:58:36.668058276 +0200
@@ -2448,7 +2448,7 @@
                 if (errno == ERANGE || errno == EINVAL || limit <= 0
                                     || strcmp (end_ptr, "") != 0) {
                         ret = -1;
-                        cli_err ("Please enter an interger value for ssh_port ");
+                        cli_err ("Please enter an integer value for ssh_port ");
                         goto out;
                 }
 
diff -Naur glusterfs-3.8rc1.orig/libglusterfs/src/gfdb/gfdb_sqlite3.c glusterfs-3.8rc1/libglusterfs/src/gfdb/gfdb_sqlite3.c
--- glusterfs-3.8rc1.orig/libglusterfs/src/gfdb/gfdb_sqlite3.c	2016-05-16 13:23:04.733009018 +0200
+++ glusterfs-3.8rc1/libglusterfs/src/gfdb/gfdb_sqlite3.c	2016-05-17 11:58:36.664058306 +0200
@@ -650,7 +650,7 @@
                                 &prep_stmt, 0);
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
-                        LG_MSG_PREPARE_FAILED, "Failed to prepare statment %s :"
+                        LG_MSG_PREPARE_FAILED, "Failed to prepare statement %s :"
                         "%s", query_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
@@ -726,7 +726,7 @@
                                &prep_stmt, 0);
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
-                        LG_MSG_PREPARE_FAILED, "Failed to prepare statment %s :"
+                        LG_MSG_PREPARE_FAILED, "Failed to prepare statement %s :"
                         " %s", query_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
@@ -826,7 +826,7 @@
                                &prep_stmt, 0);
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
-                        LG_MSG_PREPARE_FAILED, "Failed to prepare statment %s :"
+                        LG_MSG_PREPARE_FAILED, "Failed to prepare statement %s :"
                         " %s", query_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
@@ -938,7 +938,7 @@
                                 &prep_stmt, 0);
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
-                        LG_MSG_PREPARE_FAILED, "Failed to prepare statment %s :"
+                        LG_MSG_PREPARE_FAILED, "Failed to prepare statement %s :"
                         " %s", query_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
@@ -1099,7 +1099,7 @@
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED, "Failed to prepare delete "
-                        "statment %s : %s", query_str,
+                        "statement %s : %s", query_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
diff -Naur glusterfs-3.8rc1.orig/xlators/features/changetimerecorder/src/changetimerecorder.c glusterfs-3.8rc1/xlators/features/changetimerecorder/src/changetimerecorder.c
--- glusterfs-3.8rc1.orig/xlators/features/changetimerecorder/src/changetimerecorder.c	2016-05-16 13:23:04.855009642 +0200
+++ glusterfs-3.8rc1/xlators/features/changetimerecorder/src/changetimerecorder.c	2016-05-17 11:58:36.664058306 +0200
@@ -2056,7 +2056,7 @@
         if (!priv) {
                 gf_msg (this->name, GF_LOG_ERROR, ENOMEM,
                         CTR_MSG_CALLOC_FAILED,
-                        "Calloc didnt work!!!");
+                        "Calloc did not work!!!");
                 goto error;
         }
 
-------------- next part --------------
# Add missing ! in shebangs.

diff -Naur glusterfs-3.7.9.orig/extras/ganesha/scripts/create-export-ganesha.sh glusterfs-3.7.9/extras/ganesha/scripts/create-export-ganesha.sh
--- glusterfs-3.7.9.orig/extras/ganesha/scripts/create-export-ganesha.sh	2016-03-18 00:47:04.539907913 +0100
+++ glusterfs-3.7.9/extras/ganesha/scripts/create-export-ganesha.sh	2016-03-19 15:22:23.661317544 +0100
@@ -1,4 +1,4 @@
-#/bin/bash
+#!/bin/bash
 
 #This script is called by glusterd when the user
 #tries to export a volume via NFS-Ganesha.
diff -Naur glusterfs-3.7.9.orig/extras/hook-scripts/reset/post/S31ganesha-reset.sh glusterfs-3.7.9/extras/hook-scripts/reset/post/S31ganesha-reset.sh
--- glusterfs-3.7.9.orig/extras/hook-scripts/reset/post/S31ganesha-reset.sh	2016-03-18 00:47:04.543907850 +0100
+++ glusterfs-3.7.9/extras/hook-scripts/reset/post/S31ganesha-reset.sh	2016-03-19 15:23:11.228872083 +0100
@@ -1,4 +1,5 @@
-#/bin/bash
+#!/bin/bash
+
 PROGNAME="Sganesha-reset"
 OPTSPEC="volname:,gd-workdir:"
 VOL=
diff -Naur glusterfs-3.7.9.orig/extras/ganesha/scripts/dbus-send.sh glusterfs-3.7.9/extras/ganesha/scripts/dbus-send.sh
--- glusterfs-3.7.9.orig/extras/ganesha/scripts/dbus-send.sh	2016-03-18 00:47:04.540907897 +0100
+++ glusterfs-3.7.9/extras/ganesha/scripts/dbus-send.sh	2016-03-19 15:40:18.387244128 +0100
@@ -1,4 +1,4 @@
-#/bin/bash
+#!/bin/bash
 
 # Try loading the config from any of the distro
 # specific configuration locations
-------------- next part --------------
# Fix again more spelling errors.

diff -Naur glusterfs-3.8rc1.orig/doc/glusterfsd.8 glusterfs-3.8rc1/doc/glusterfsd.8
--- glusterfs-3.8rc1.orig/doc/glusterfsd.8	2016-05-16 13:23:04.694008818 +0200
+++ glusterfs-3.8rc1/doc/glusterfsd.8	2016-05-17 11:59:39.623592333 +0200
@@ -103,7 +103,7 @@
 Enable/Disable direct-io mode in fuse module [default: enable]
 .TP
 \fB\-\-resolve-gids\fR
-Resolve all auxilary groups in fuse translator (max 32 otherwise)
+Resolve all auxiliary groups in fuse translator (max 32 otherwise)
 
 .SS "Miscellaneous Options"
 .PP
diff -Naur glusterfs-3.8rc1.orig/doc/mount.glusterfs.8 glusterfs-3.8rc1/doc/mount.glusterfs.8
--- glusterfs-3.8rc1.orig/doc/mount.glusterfs.8	2016-05-17 11:55:34.993402832 +0200
+++ glusterfs-3.8rc1/doc/mount.glusterfs.8	2016-05-17 11:59:39.623592333 +0200
@@ -80,7 +80,7 @@
 Set fuse module's background queue length to N [default: 64]
 .TP
 \fBgid\-timeout=\fRSECONDS
-Set auxilary group list timeout to SECONDS for fuse translator [default: 0]
+Set auxiliary group list timeout to SECONDS for fuse translator [default: 0]
 .TP
 \fBnegative\-timeout=\fRSECONDS
 Set negative timeout to SECONDS in fuse kernel module [default: 0]
diff -Naur glusterfs-3.8rc1.orig/glusterfsd/src/glusterfsd.c glusterfs-3.8rc1/glusterfsd/src/glusterfsd.c
--- glusterfs-3.8rc1.orig/glusterfsd/src/glusterfsd.c	2016-05-16 13:23:04.717008936 +0200
+++ glusterfs-3.8rc1/glusterfsd/src/glusterfsd.c	2016-05-17 11:59:39.623592333 +0200
@@ -198,10 +198,10 @@
          "Set attribute timeout to SECONDS for inodes in fuse kernel module "
          "[default: 1]"},
 	{"gid-timeout", ARGP_GID_TIMEOUT_KEY, "SECONDS", 0,
-	 "Set auxilary group list timeout to SECONDS for fuse translator "
+	 "Set auxiliary group list timeout to SECONDS for fuse translator "
 	 "[default: 300]"},
         {"resolve-gids", ARGP_RESOLVE_GIDS_KEY, 0, 0,
-         "Resolve all auxilary groups in fuse translator (max 32 otherwise)"},
+         "Resolve all auxiliary groups in fuse translator (max 32 otherwise)"},
 	{"background-qlen", ARGP_FUSE_BACKGROUND_QLEN_KEY, "N", 0,
 	 "Set fuse module's background queue length to N "
 	 "[default: 64]"},
diff -Naur glusterfs-3.8rc1.orig/xlators/mgmt/glusterd/src/glusterd-quota.c glusterfs-3.8rc1/xlators/mgmt/glusterd/src/glusterd-quota.c
--- glusterfs-3.8rc1.orig/xlators/mgmt/glusterd/src/glusterd-quota.c	2016-05-16 13:23:04.883009785 +0200
+++ glusterfs-3.8rc1/xlators/mgmt/glusterd/src/glusterd-quota.c	2016-05-17 11:59:39.623592333 +0200
@@ -2047,7 +2047,7 @@
                 if (ret) {
                         gf_msg (this->name, GF_LOG_ERROR, 0,
                                 GD_MSG_DICT_GET_FAILED,
-                                "Faild to get hard-limit from dict");
+                                "Failed to get hard-limit from dict");
                         goto out;
                 }
                 ret = gf_string2bytesize_int64 (hard_limit_str, &hard_limit);
-------------- next part --------------
# Fix lintian warning hyphen-used-as-minus-sign.

diff -Naur glusterfs-3.7.9.orig/doc/mount.glusterfs.8 glusterfs-3.7.9/doc/mount.glusterfs.8
--- glusterfs-3.7.9.orig/doc/mount.glusterfs.8	2016-03-18 00:47:04.530908051 +0100
+++ glusterfs-3.7.9/doc/mount.glusterfs.8	2016-03-19 14:43:05.219329552 +0100
@@ -99,7 +99,7 @@
 \fBbackup\-volfile\-servers=\fRSERVERLIST
 Provide list of backup volfile servers in the following format [default: None]
 
-\fB$ mount -t glusterfs -obackup-volfile-servers=<server2>:\fR
+\fB$ mount \-t glusterfs \-obackup\-volfile\-servers=<server2>:\fR
 \fB       <server3>:...:<serverN> <server1>:/<volname> <mount_point>\fR
 
 .TP
@@ -107,7 +107,7 @@
 \fBbackupvolfile\-server=\fRSERVER
 Provide list of backup volfile servers in the following format [default: None]
 
-\fB $ mount -t glusterfs -obackupvolfile-server=<server2>
+\fB $ mount \-t glusterfs \-obackupvolfile\-server=<server2>
 \fB         <server1>:/<volname> <mount_point>
 
 .TP
-------------- next part --------------
# Fix bashishms in shell scripts.

diff -Naur glusterfs-3.8rc1.orig/extras/stop-all-gluster-processes.sh glusterfs-3.8rc1/extras/stop-all-gluster-processes.sh
--- glusterfs-3.8rc1.orig/extras/stop-all-gluster-processes.sh	2016-05-16 13:23:04.709008895 +0200
+++ glusterfs-3.8rc1/extras/stop-all-gluster-processes.sh	2016-05-17 11:54:50.905729153 +0200
@@ -64,7 +64,7 @@
     fi
 }
 
-function main()
+main()
 {
     kill_mounts TERM
     kill_bricks_and_services TERM
diff -Naur glusterfs-3.8rc1.orig/tools/gfind_missing_files/gfid_to_path.sh glusterfs-3.8rc1/tools/gfind_missing_files/gfid_to_path.sh
--- glusterfs-3.8rc1.orig/tools/gfind_missing_files/gfid_to_path.sh	2016-05-16 13:23:04.812009422 +0200
+++ glusterfs-3.8rc1/tools/gfind_missing_files/gfid_to_path.sh	2016-05-17 11:54:50.905729153 +0200
@@ -11,7 +11,7 @@
 E_BADARGS=65
 
 
-function gfid_to_path()
+gfid_to_path ()
 {
     brick_dir=$1;
     gfid_file=$(readlink -e $2);
@@ -29,7 +29,8 @@
 }
 
 
-function main(){
+main ()
+{
     if [ $# -ne 2 ]
     then
         echo "Usage: `basename $0` BRICK_DIR GFID_FILE";
diff -Naur glusterfs-3.8rc1.orig/tools/gfind_missing_files/gfind_missing_files.sh glusterfs-3.8rc1/tools/gfind_missing_files/gfind_missing_files.sh
--- glusterfs-3.8rc1.orig/tools/gfind_missing_files/gfind_missing_files.sh	2016-05-16 13:23:04.812009422 +0200
+++ glusterfs-3.8rc1/tools/gfind_missing_files/gfind_missing_files.sh	2016-05-17 11:54:50.905729153 +0200
@@ -14,18 +14,18 @@
 SLAVEMNT=     #Slave gluster volume mount point
 WORKERS=4     #Default number of worker threads
 
-function out()
+out()
 {
     echo "$@";
 }
 
-function fatal()
+fatal()
 {
     out FATAL "$@";
     exit 1
 }
 
-function ping_host ()
+ping_host ()
 {
     ### Use bash internal socket support
     {
@@ -39,7 +39,7 @@
     } 1>&2 2>/dev/null
 }
 
-function mount_slave()
+mount_slave()
 {
     local i; # inode number
     SSH_PORT=22
@@ -59,7 +59,7 @@
     [ "x$i" = "x1" ] || fatal "Could not mount volume $2 on $SLAVEMNT Please check host and volume exists";
 }
 
-function parse_cli()
+parse_cli()
 {
     if [[ $# -ne 4 ]]; then
         echo "Usage: gfind_missing_files <brick-path> <slave-host> <slave-vol> <OUTFILE>"
@@ -76,7 +76,7 @@
     fi
 }
 
-function main()
+main()
 {
     parse_cli "$@";
 
-------------- next part --------------
# Fix again some more spelling errors.

diff -Naur glusterfs-3.8rc1.orig/cli/src/cli-rpc-ops.c glusterfs-3.8rc1/cli/src/cli-rpc-ops.c
--- glusterfs-3.8rc1.orig/cli/src/cli-rpc-ops.c	2016-05-16 13:23:04.675008721 +0200
+++ glusterfs-3.8rc1/cli/src/cli-rpc-ops.c	2016-05-17 11:55:47.929307114 +0200
@@ -4593,7 +4593,7 @@
 notify_cli:
         if (ret) {
                 cli_out ("Failed to run tier start. Please execute tier start "
-                         "command explictly");
+                         "command explicitly");
                 cli_out ("Usage : gluster volume rebalance <volname> tier "
                          "start");
         }
-------------- next part --------------
# Fix again and again more spelling errors.

diff -Naur glusterfs-3.8rc1.orig/xlators/cluster/ec/src/ec-common.c glusterfs-3.8rc1/xlators/cluster/ec/src/ec-common.c
--- glusterfs-3.8rc1.orig/xlators/cluster/ec/src/ec-common.c	2016-05-16 13:23:04.831009519 +0200
+++ glusterfs-3.8rc1/xlators/cluster/ec/src/ec-common.c	2016-05-17 11:56:27.277015911 +0200
@@ -456,7 +456,7 @@
     {
         gf_msg (ec->xl->name, GF_LOG_ERROR, 0,
                 EC_MSG_CHILDS_INSUFFICIENT,
-                "Insufficient available childs "
+                "Insufficient available children "
                 "for this request (have %d, need "
                 "%d)", num, fop->minimum);
 
diff -Naur glusterfs-3.8rc1.orig/xlators/mgmt/glusterd/src/glusterd-rebalance.c glusterfs-3.8rc1/xlators/mgmt/glusterd/src/glusterd-rebalance.c
--- glusterfs-3.8rc1.orig/xlators/mgmt/glusterd/src/glusterd-rebalance.c	2016-05-16 13:23:04.883009785 +0200
+++ glusterfs-3.8rc1/xlators/mgmt/glusterd/src/glusterd-rebalance.c	2016-05-17 11:56:27.277015911 +0200
@@ -1104,7 +1104,7 @@
         } else {
                 gf_msg (this->name, GF_LOG_ERROR, 0,
                         GD_MSG_NO_REBALANCE_PFX_IN_VOLNAME,
-                        "volname recieved (%s) is not prefixed with rebalance.",
+                        "volname received (%s) is not prefixed with rebalance.",
                         volname);
                 ret = -1;
                 goto out;
diff -Naur glusterfs-3.8rc1.orig/xlators/mgmt/glusterd/src/glusterd-rpc-ops.c glusterfs-3.8rc1/xlators/mgmt/glusterd/src/glusterd-rpc-ops.c
--- glusterfs-3.8rc1.orig/xlators/mgmt/glusterd/src/glusterd-rpc-ops.c	2016-05-16 13:23:04.884009790 +0200
+++ glusterfs-3.8rc1/xlators/mgmt/glusterd/src/glusterd-rpc-ops.c	2016-05-17 11:56:27.281015881 +0200
@@ -419,7 +419,7 @@
         GLUSTERD_STACK_DESTROY (((call_frame_t *)myframe));
 
         /* Attempt to start the state machine. Needed as no state machine could
-         * be running at time this RPC reply was recieved
+         * be running at time this RPC reply was received
          */
         if (!ret) {
                 glusterd_friend_sm ();
-------------- next part --------------
A non-text attachment was scrubbed...
Name: signature.asc
Type: application/pgp-signature
Size: 819 bytes
Desc: OpenPGP digital signature
URL: <http://www.gluster.org/pipermail/maintainers/attachments/20160517/c86d3e63/attachment-0001.sig>


More information about the maintainers mailing list
diff -Naur glusterfs-3.8rc1.orig/libglusterfs/src/gfdb/gfdb_sqlite3_helper.c glusterfs-3.8rc1/libglusterfs/src/gfdb/gfdb_sqlite3_helper.c
--- glusterfs-3.8rc1.orig/libglusterfs/src/gfdb/gfdb_sqlite3_helper.c	2016-05-16 13:23:04.734009023 +0200
+++ glusterfs-3.8rc1/libglusterfs/src/gfdb/gfdb_sqlite3_helper.c	2016-05-17 11:58:36.664058306 +0200
@@ -48,7 +48,7 @@
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED, "Failed preparing delete "
-                        "statment %s : %s", delete_link_str,
+                        "statement %s : %s", delete_link_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
@@ -88,7 +88,7 @@
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED, "Failed preparing delete "
-                        "statment %s : %s", delete_file_str,
+                        "statement %s : %s", delete_file_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
@@ -148,7 +148,7 @@
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED, "Failed preparing delete "
-                        "statment %s : %s", delete_str,
+                        "statement %s : %s", delete_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
@@ -243,7 +243,7 @@
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED, "Failed preparing update "
-                        "statment %s : %s", update_str,
+                        "statement %s : %s", update_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
@@ -345,7 +345,7 @@
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED,
                         "Failed preparing insert "
-                        "statment %s : %s", insert_str,
+                        "statement %s : %s", insert_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
@@ -459,7 +459,7 @@
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED, "Failed preparing insert "
-                        "statment %s : %s", insert_str,
+                        "statement %s : %s", insert_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
@@ -542,7 +542,7 @@
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED, "Failed preparing insert "
-                        "statment %s : %s", insert_str,
+                        "statement %s : %s", insert_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
@@ -621,7 +621,7 @@
         GF_VALIDATE_OR_GOTO (GFDB_STR_SQLITE3, update_time, out);
 
         /*
          * Constructing the prepare statment string.
          *
          * */
         /*For write time*/
@@ -671,7 +671,7 @@
         if (ret != SQLITE_OK) {
                 gf_msg (GFDB_STR_SQLITE3, GF_LOG_ERROR, 0,
                         LG_MSG_PREPARE_FAILED, "Failed preparing insert "
-                        "statment %s : %s", update_str,
+                        "statement %s : %s", update_str,
                         sqlite3_errmsg (sql_conn->sqlite3_db_conn));
                 ret = -1;
                 goto out;
@@ -621,7 +621,7 @@
 
         /*
-         * Constructing the prepare statment string.
+         * Constructing the prepare statement string.
          *
          * */